Examples
========


Slideshow
---------

Try clicking the image 🖱️

.. example:: slideshow


Click Counter
-------------

.. example:: click_count


To Do List
----------

Try typing in the text box and pressing 'Enter' 📋

.. example:: todo


The Game Snake
--------------

Click to start playing and use the arrow keys to move 🎮

Slow internet may cause inconsistent frame pacing 😅

.. example:: snake_game


Matplotlib Plot
---------------

Pick the polynomial coefficients (seperate each coefficient by a space) 🔢:

.. example:: matplotlib_plot


Simple Dashboard
----------------

Try interacting with the sliders 📈

.. example:: simple_dashboard


Install Javascript Modules
--------------------------

Simply install your javascript library of choice using the ``idom`` CLI:

.. code-block:: bash

    idom install victory

Then import the module with :class:`~idom.widgets.utils.Module`:

.. example:: victory_chart


Define Javascript Modules
-------------------------

Assuming you already installed ``victory`` as in the :ref:`Install Javascript Modules` section:

Click the bars to trigger an event 👇

.. example:: super_simple_chart


Material UI Slider
------------------

Assuming you already installed ``@material-ui/core`` as in the :ref:`Install Javascript Modules` section:

Move the slider and see the event information update 👇

.. example:: material_ui_slider


.. Links
.. =====

.. |launch-binder| image:: https://mybinder.org/badge_logo.svg
 :target: https://mybinder.org/v2/gh/idom-team/idom-jupyter/main?filepath=examples%2Fintroduction.ipynb
